======================
CHANGELOG for Trashman
======================
:Author: Chris Warrick <chris@chriswarrick.com>
:Copyright: © 2011–2015, Chris Warrick.
:License: BSD (see /LICENSE or :doc:`Appendix B <LICENSE>`.)
:Date: 2015-03-07
:Version: 1.5.0

.. index:: CHANGELOG


GitHub holds releases, too
==========================

More information can be found on GitHub in the `releases section
<https://github.com/Kwpolska/python-project-template/releases>`_.

Version History
===============

1.5.0
-----

1.5.0
    A big modernization of Trashman.

1.0.0
-----

1.0.4
    Minor fixes.

1.0.3
    I do not like the word “exit”.

1.0.2
    Fixes #2, creating config dirs properly.  (the app crashed if there was no ~/.config/kwpolska/ dir.  This bug wasn’t found due to having PKGBUILDer installed, which was creating that directory.)

1.0.1
    Bugfix release.

1.0.0
    A complete modification of the approach, now using a concept of “backends”, allowing multiple trash systems to be used.

0.2.0
-----

0.2.4.1 (semi-official)
    Locale fix #3, only pypi/aur

0.2.4
    Zsh completions.

0.2.3
    Locale fix #2

0.2.2
    Locale fix #1

0.2.1
    Localization support.

0.2.0
    Documentation.  The project became a bit more mature now.

0.1.0
-----

0.1.3
    Fixed some problems with file restoration.

0.1.2
    Ommited a character, also added restoration to --help.

0.1.1
    Restoration magic.

0.1.0
    Initial release.
